@@ -1,6 +1,6 @@
 package Hailo::Storage::Schema;
 BEGIN {
-  $Hailo::Storage::Schema::VERSION = '0.39';
+  $Hailo::Storage::Schema::VERSION = '0.40';
 }
 
 use 5.010;
@@ -100,7 +100,7 @@ sub sth {
     $q_rand_id    = "(random()*id+1)::int" if $dbd eq 'Pg';
 
     my %state = (
-        set_order        => qq[INSERT INTO info (attribute, text) VALUES ('markov_order', ?);],
+        set_info         => qq[INSERT INTO info (attribute, text) VALUES (?, ?);],
 
         random_expr      => qq[SELECT * FROM expr WHERE id >= $q_rand_id LIMIT 1;],
         token_id         => qq[SELECT id FROM token WHERE spacing = ? AND text = ?;],
@@ -147,12 +147,6 @@ sub sth {
             $state{prev_total}       = qq[SELECT seq FROM sqlite_sequence WHERE name = 'prev_token';];
             $state{next_total}       = qq[SELECT seq FROM sqlite_sequence WHERE name = 'next_token';];
         }
-        when ('Pg') {
-            $state{exists_db} = qq[SELECT count(*) FROM information_schema.columns WHERE table_name ='info';];
-        }
-        when ('mysql') {
-            $state{exists_db} = qq[SHOW TABLES;];
-        }
     }
 
     # Sort to make error output easier to read if this fails. The
