@@ -261,14 +261,15 @@ sub train_a_few_tokens {
     my @chr = map { chr } 50..120;
     my @random_tokens = map { $chr[rand @chr] } 1 .. 30;
 
-    pass("About to learn from <<@random_tokens>>");
     # Learn from it
     if ((int rand 2) == 1) {
         eval {
-            $hailo->learn( \@random_tokens );
+            pass("About to learn from <<@random_tokens>>. Via ArrayRef");
+            $hailo->learn( [ "@random_tokens" ] );
         };
     } else {
         eval {
+            pass("About to learn from <<@random_tokens>>. Via Str");
             $hailo->learn( "@random_tokens" );
         };
     }
@@ -391,8 +392,8 @@ sub test_timtoady {
         ok(defined $reply, "$storage: Got a reply to <<$_>> = <<$reply>>");
     }
 
-    for my $i (0 .. $lns) {
-        chomp(my $line = <$fh>);
+    for my $i (0 .. ($lns-1)) {
+        my $line = <$fh>;
         my $reply = $hailo->reply($line);
         ok(defined $reply, "$storage: Got a reply to <<$line>> = <<$reply>>");
     }
@@ -407,9 +408,10 @@ sub test_babble {
 
     for (1 .. 10) {
         my ($err, $tokens) = $self->train_a_few_tokens();
+        ok(!$err, "No error: '$err'");
 
         my $input = $tokens->[5];
-        pass("Training on <<$input>>");
+        pass("Replying to <<$input>>");
         my $reply = $hailo->reply($input);
         # Hailo replies
         cmp_ok(length($reply) * 2, '>', length($input), "$storage: Hailo knows how to babble, said '$reply' given '$input'");
@@ -462,13 +464,13 @@ sub test_all_plan {
     plan skip_all => "Skipping $storage tests, can't create storage" unless $ok;
     if ($self->exhaustive) {
         if ($self->brief) {
-            plan(tests => 788);
+            plan(tests => 797);
         } else {
-            plan(tests => 29977);
+            plan(tests => 253420);
         }
         $self->test_exhaustive;
     } else {
-        plan(tests => 997);
+        plan(tests => 1007);
         $self->test_all;
     }
   }
